@@ -1,7 +1,7 @@
 /* buffer.c: scratch-file buffer routines for the ed line editor. */
 /* GNU ed - The GNU line editor.
    Copyright (C) 1993, 1994 Andrew L. Moore, Talke Studio
-   Copyright (C) 2006-2024 Antonio Diaz Diaz.
+   Copyright (C) 2006-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -23,8 +23,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
-#include <sys/file.h>
-#include <sys/stat.h>
 
 #include "ed.h"
 
@@ -37,8 +35,8 @@ static unsigned char modified_ = false;	/* 1=modified | 2=warned */
 static bool seek_write = false;	/* seek before writing */
 static FILE * sfp = 0;		/* scratch file pointer */
 static long sfpos = 0;		/* scratch file position */
-static line_t buffer_head;	/* editor buffer ( linked list of line_t ) */
-static line_t yank_buffer_head;
+static line_node buffer_head;	/* editor buffer (linked list of line_node) */
+static line_node yank_buffer_head;
 
 
 int current_addr( void ) { return current_addr_; }
@@ -57,7 +55,7 @@ void set_modified( const bool b ) { modified_ = b != 0; }  /* clear warned */
 bool warned( void ) { return modified_ == 3; }
 void set_warned( const bool b ) { if( b ) modified_ |= 2; else modified_ &= 1; }
 
-/* line 0 does not contain text, but it is part of the linked list of line_t.
+/* line 0 does not contain text, but it is part of the linked list of line_node.
    Therefore inc_addr and dec_addr must cycle through addr 0. */
 int inc_addr( int addr )
   { if( ++addr > last_addr_ ) addr = 0; return addr; }
@@ -67,12 +65,12 @@ int dec_addr( int addr )
 
 
 /* link next and previous nodes */
-static void link_nodes( line_t * const prev, line_t * const next )
+static void link_nodes( line_node * const prev, line_node * const next )
   { prev->q_forw = next; next->q_back = prev; }
 
 
 /* insert line node into circular queue after previous */
-static void insert_node( line_t * const lp, line_t * const prev )
+static void insert_node( line_node * const lp, line_node * const prev )
   {
   link_nodes( lp, prev->q_forw );
   link_nodes( prev, lp );
@@ -87,9 +85,9 @@ static bool too_many_lines( void )
   }
 
 /* add a line node in the editor buffer after the given line */
-static void add_line_node( line_t * const lp )
+static void add_line_node( line_node * const lp )
   {
-  line_t * const prev = search_line_node( current_addr_ );
+  line_node * const prev = search_line_node( current_addr_ );
   insert_node( lp, prev );
   ++current_addr_;
   ++last_addr_;
@@ -97,9 +95,9 @@ static void add_line_node( line_t * const lp )
 
 
 /* return a pointer to a copy of a line node, or to a new node if lp == 0 */
-static line_t * dup_line_node( line_t * const lp )
+static line_node * dup_line_node( line_node * const lp )
   {
-  line_t * const p = (line_t *) malloc( sizeof (line_t) );
+  line_node * const p = (line_node *) malloc( sizeof (line_node) );
   if( !p )
     {
     show_strerror( 0, errno );
@@ -119,7 +117,7 @@ bool append_lines( const char ** const ibufpp, const int addr,
                    bool insert, const bool isglobal )
   {
   int size = 0;
-  undo_t * up = 0;
+  undo_atom * up = 0;
   current_addr_ = addr;
 
   while( true )
@@ -155,12 +153,12 @@ bool append_lines( const char ** const ibufpp, const int addr,
 
 static void clear_yank_buffer( void )
   {
-  line_t * lp = yank_buffer_head.q_forw;
+  line_node * lp = yank_buffer_head.q_forw;
 
   disable_interrupts();
   while( lp != &yank_buffer_head )
     {
-    line_t * const p = lp->q_forw;
+    line_node * const p = lp->q_forw;
     link_nodes( lp->q_back, lp->q_forw );
     free( lp );
     lp = p;
@@ -193,8 +191,8 @@ bool close_sbuf( void )
 /* copy a range of lines; return false if error */
 bool copy_lines( const int first_addr, const int second_addr, const int addr )
   {
-  line_t *lp, *np = search_line_node( first_addr );
-  undo_t * up = 0;
+  line_node * np = search_line_node( first_addr );
+  undo_atom * up = 0;
   int n = second_addr - first_addr + 1;
   int m = 0;
 
@@ -209,7 +207,7 @@ bool copy_lines( const int first_addr, const int second_addr, const int addr )
       {
       if( too_many_lines() ) return false;
       disable_interrupts();
-      lp = dup_line_node( np );
+      line_node * lp = dup_line_node( np );
       if( !lp ) { enable_interrupts(); return false; }
       add_line_node( lp );
       if( up ) up->tail = lp;
@@ -228,14 +226,12 @@ bool copy_lines( const int first_addr, const int second_addr, const int addr )
 /* delete a range of lines */
 bool delete_lines( const int from, const int to, const bool isglobal )
   {
-  line_t *n, *p;
-
   if( !yank_lines( from, to ) ) return false;
   disable_interrupts();
   if( !push_undo_atom( UDEL, from, to ) )
     { enable_interrupts(); return false; }
-  n = search_line_node( inc_addr( to ) );
-  p = search_line_node( from - 1 );	/* this search_line_node last! */
+  line_node * n = search_line_node( inc_addr( to ) );
+  line_node * p = search_line_node( from - 1 );	/* this search_line_node last! */
   if( isglobal ) unset_active_nodes( p->q_forw, n );
   link_nodes( p, n );
   last_addr_ -= to - from + 1;
@@ -247,9 +243,9 @@ bool delete_lines( const int from, const int to, const bool isglobal )
 
 
 /* return line number of pointer */
-int get_line_node_addr( const line_t * const lp )
+int get_line_node_addr( const line_node * const lp )
   {
-  const line_t * p = &buffer_head;
+  const line_node * p = &buffer_head;
   int addr = 0;
 
   while( p != lp && ( p = p->q_forw ) != &buffer_head ) ++addr;
@@ -259,7 +255,7 @@ int get_line_node_addr( const line_t * const lp )
 
 
 /* get a line of text from the scratch file; return pointer to the text */
-char * get_sbuf_line( const line_t * const lp )
+char * get_sbuf_line( const line_node * const lp )
   {
   static char * buf = 0;
   static int bufsz = 0;
@@ -315,8 +311,8 @@ bool join_lines( const int from, const int to, const bool isglobal )
   static char * buf = 0;
   static int bufsz = 0;
   int size = 0;
-  line_t * const ep = search_line_node( inc_addr( to ) );
-  line_t * bp = search_line_node( from );
+  line_node * const ep = search_line_node( inc_addr( to ) );
+  line_node * bp = search_line_node( from );
 
   while( bp != ep )
     {
@@ -345,7 +341,7 @@ bool join_lines( const int from, const int to, const bool isglobal )
 bool move_lines( const int first_addr, const int second_addr, const int addr,
                  const bool isglobal )
   {
-  line_t *b1, *a1, *b2, *a2;
+  line_node *b1, *a1, *b2, *a2;
   int n = inc_addr( second_addr );
   int p = first_addr - 1;
 
@@ -415,8 +411,8 @@ int path_max( const char * filename )
 /* append lines from the yank buffer */
 bool put_lines( const int addr )
   {
-  undo_t * up = 0;
-  line_t *p, *lp = yank_buffer_head.q_forw;
+  undo_atom * up = 0;
+  line_node * lp = yank_buffer_head.q_forw;
 
   if( lp == &yank_buffer_head )
     { set_error_msg( "Nothing to put" ); return false; }
@@ -425,7 +421,7 @@ bool put_lines( const int addr )
     {
     if( too_many_lines() ) return false;
     disable_interrupts();
-    p = dup_line_node( lp );
+    line_node * p = dup_line_node( lp );
     if( !p ) { enable_interrupts(); return false; }
     add_line_node( p );
     if( up ) up->tail = p;
@@ -474,7 +470,7 @@ const char * put_sbuf_line( const char * const buf, const int size )
     set_error_msg( "Cannot write temp file" );
     return 0;
     }
-  line_t * lp = dup_line_node( 0 );
+  line_node * lp = dup_line_node( 0 );
   if( !lp ) return 0;
   lp->pos = sfpos; lp->len = len;
   add_line_node( lp );
@@ -484,9 +480,9 @@ const char * put_sbuf_line( const char * const buf, const int size )
 
 
 /* return pointer to a line node in the editor buffer */
-line_t * search_line_node( const int addr )
+line_node * search_line_node( const int addr )
   {
-  static line_t * lp = &buffer_head;
+  static line_node * lp = &buffer_head;
   static int o_addr = 0;
 
   disable_interrupts();
@@ -513,16 +509,15 @@ line_t * search_line_node( const int addr )
 /* copy a range of lines to the cut buffer */
 bool yank_lines( const int from, const int to )
   {
-  line_t * const ep = search_line_node( inc_addr( to ) );
-  line_t * bp = search_line_node( from );
-  line_t * lp = &yank_buffer_head;
-  line_t * p;
+  line_node * const ep = search_line_node( inc_addr( to ) );
+  line_node * bp = search_line_node( from );
+  line_node * lp = &yank_buffer_head;
 
   clear_yank_buffer();
   while( bp != ep )
     {
     disable_interrupts();
-    p = dup_line_node( bp );
+    line_node * p = dup_line_node( bp );
     if( !p ) { enable_interrupts(); return false; }
     insert_node( p, lp );
     bp = bp->q_forw; lp = p;
@@ -532,9 +527,9 @@ bool yank_lines( const int from, const int to )
   }
 
 
-static undo_t * ustack = 0;		/* undo stack */
+static undo_atom * ustack = 0;		/* undo stack */
 static int usize = 0;			/* ustack size (in bytes) */
-static int u_idx = 0;			/* undo stack index */
+static int u_len = 0;			/* undo stack size (in atoms) */
 static int u_current_addr = -1;		/* if < 0, undo disabled */
 static int u_last_addr = -1;		/* if < 0, undo disabled */
 static bool u_modified = false;
@@ -542,21 +537,21 @@ static bool u_modified = false;
 
 void clear_undo_stack( void )
   {
-  while( u_idx-- )
-    if( ustack[u_idx].type == UDEL )
+  while( u_len-- )
+    if( ustack[u_len].type == UDEL )
       {
-      line_t * const ep = ustack[u_idx].tail->q_forw;
-      line_t * bp = ustack[u_idx].head;
+      line_node * const ep = ustack[u_len].tail->q_forw;
+      line_node * bp = ustack[u_len].head;
       while( bp != ep )
         {
-        line_t * const lp = bp->q_forw;
+        line_node * const lp = bp->q_forw;
         unmark_line_node( bp );
         unmark_unterminated_line( bp );
         free( bp );
         bp = lp;
         }
       }
-  u_idx = 0;
+  u_len = 0;
   u_current_addr = current_addr_;
   u_last_addr = last_addr_;
   u_modified = modified();
@@ -578,16 +573,16 @@ static void free_undo_stack( void )
     clear_undo_stack();
     free( ustack );
     ustack = 0;
-    usize = u_idx = 0;
+    usize = u_len = 0;
     u_current_addr = u_last_addr = -1;
     }
   }
 
 
-/* return pointer to intialized undo node */
-undo_t * push_undo_atom( const int type, const int from, const int to )
+/* return pointer to intialized undo atom */
+undo_atom * push_undo_atom( const int type, const int from, const int to )
   {
-  const unsigned min_size = ( u_idx + 1 ) * sizeof (undo_t);
+  const unsigned min_size = ( u_len + 1 ) * sizeof (undo_atom);
 
   disable_interrupts();
   if( (unsigned)usize < min_size )
@@ -604,13 +599,13 @@ undo_t * push_undo_atom( const int type, const int from, const int to )
       { show_strerror( 0, errno ); set_error_msg( mem_msg );
         free_undo_stack(); enable_interrupts(); return 0; }
     usize = new_size;
-    ustack = (undo_t *)new_buf;
+    ustack = (undo_atom *)new_buf;
     }
-  ustack[u_idx].type = type;
-  ustack[u_idx].tail = search_line_node( to );
-  ustack[u_idx].head = search_line_node( from );
+  ustack[u_len].type = type;
+  ustack[u_len].tail = search_line_node( to );
+  ustack[u_len].head = search_line_node( from );
   enable_interrupts();
-  return ustack + u_idx++;
+  return ustack + u_len++;
   }
 
 
@@ -622,11 +617,11 @@ bool undo( const bool isglobal )
   const int o_last_addr = last_addr_;
   const bool o_modified = modified();
 
-  if( u_idx <= 0 || u_current_addr < 0 || u_last_addr < 0 )
+  if( u_len <= 0 || u_current_addr < 0 || u_last_addr < 0 )
     { set_error_msg( "Nothing to undo" ); return false; }
   search_line_node( 0 );		/* reset cached value */
   disable_interrupts();
-  for( n = u_idx - 1; n >= 0; --n )
+  for( n = u_len - 1; n >= 0; --n )
     {
     switch( ustack[n].type )
       {
@@ -644,10 +639,10 @@ bool undo( const bool isglobal )
     ustack[n].type ^= 1;
     }
   /* reverse undo stack order */
-  for( n = 0; 2 * n < u_idx - 1; ++n )
+  for( n = 0; n < u_len - 1 - n; ++n )
     {
-    undo_t tmp = ustack[n];
-    ustack[n] = ustack[u_idx-1-n]; ustack[u_idx-1-n] = tmp;
+    undo_atom tmp = ustack[n];
+    ustack[n] = ustack[u_len-1-n]; ustack[u_len-1-n] = tmp;
     }
   if( isglobal ) clear_active_list();
   current_addr_ = u_current_addr; u_current_addr = o_current_addr;
