@@ -35,8 +35,8 @@ void unmark_unterminated_line( const line_node * const lp )
   { if( unterminated_line == lp ) unterminated_line = 0; }
 
 static bool unterminated_last_line( void )
-  { return ( unterminated_line != 0 &&
-             unterminated_line == search_line_node( last_addr() ) ); }
+  { return unterminated_line != 0 &&
+           unterminated_line == search_line_node( last_addr() ); }
 
 
 /* print text to stdout */
@@ -59,7 +59,7 @@ static void print_line( const char * p, int len, const int pflags )
           putchar( ch ); }
       else
         {
-        char * const p = strchr( escapes, ch );
+        const char * const p = strchr( escapes, ch );
         ++col; putchar('\\');
         if( ch && p ) putchar( escchars[p-escapes] );
         else
