@@ -1,7 +1,7 @@
 /* regex.c: regular expression interface routines for the ed line editor. */
 /* GNU ed - The GNU line editor.
    Copyright (C) 1993, 1994 Andrew L. Moore, Talke Studio
-   Copyright (C) 2006-2024 Antonio Diaz Diaz.
+   Copyright (C) 2006-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,11 +17,7 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <stddef.h>
-#include <errno.h>
 #include <regex.h>
-#include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
 
 #include "ed.h"
@@ -77,7 +73,7 @@ static const char * parse_char_class( const char * p )
       for( ++p, c = *++p; *p != ']' || c != d; ++p )
         if( islf_or_nul( c = *p ) )
           return 0;
-  return ( ( *p == ']' ) ? p : 0 );
+  return ( *p == ']' ) ? p : 0;
   }
 
 
@@ -202,7 +198,7 @@ bool set_subst_regex( const char * const pat, const bool ignore_case )
     subst_regexp = exp;
     }
   enable_interrupts();
-  return ( exp ? true : false );
+  return exp ? true : false;
   }
 
 
@@ -230,7 +226,7 @@ bool build_active_list( const char ** const ibufpp, const int first_addr,
   const regex_t * const exp = get_compiled_regex( ibufpp );
   if( !exp ) return false;
   clear_active_list();
-  const line_t * lp = search_line_node( first_addr );
+  const line_node * lp = search_line_node( first_addr );
   for( addr = first_addr; addr <= second_addr; ++addr, lp = lp->q_forw )
     {
     char * const s = get_sbuf_line( lp );
@@ -256,7 +252,7 @@ int next_matching_node_addr( const char ** const ibufpp )
     addr = ( forward ? inc_addr( addr ) : dec_addr( addr ) );
     if( addr )
       {
-      const line_t * const lp = search_line_node( addr );
+      const line_node * const lp = search_line_node( addr );
       char * const s = get_sbuf_line( lp );
       if( !s ) return -1;
       if( isbinary() ) nul_to_newline( s, lp->len );
@@ -353,7 +349,7 @@ static int replace_matched_text( char ** txtbufp, int * const txtbufszp,
 /* Produce new text with one or all matches replaced in a line.
    Return size of the new line text, 0 if no change, -1 if error */
 static int line_replace( char ** txtbufp, int * const txtbufszp,
-                         const line_t * const lp, const int snum )
+                         const line_node * const lp, const int snum )
   {
   enum { se_max = 30 };	/* max subexpressions in a regular expression */
   regmatch_t rm[se_max];
@@ -401,7 +397,7 @@ static int line_replace( char ** txtbufp, int * const txtbufszp,
     memcpy( *txtbufp + offset, txt, i );		/* tail copy */
     memcpy( *txtbufp + offset + i, "\n", 2 );
     }
-  return ( changed ? offset + i + 1 : 0 );
+  return changed ? offset + i + 1 : 0;
   }
 
 
@@ -418,14 +414,14 @@ bool search_and_replace( const int first_addr, const int second_addr,
 
   for( lc = 0; lc <= second_addr - first_addr; ++lc, ++addr )
     {
-    const line_t * const lp = search_line_node( addr );
+    const line_node * const lp = search_line_node( addr );
     const int size = line_replace( &txtbuf, &txtbufsz, lp, snum );
     if( size < 0 ) return false;
     if( size )
       {
       const char * txt = txtbuf;
       const char * const eot = txtbuf + size;
-      undo_t * up = 0;
+      undo_atom * up = 0;
       disable_interrupts();
       if( !delete_lines( addr, addr, isglobal ) )
         { enable_interrupts(); return false; }
